pub enum SerializationError {
Io(Arc<Error>),
Parse(&'static str),
Utf8Error(Utf8Error),
TryFromSliceError(TryFromSliceError),
TryFromIntError(TryFromIntError),
FromHexError(FromHexError),
Amount {
source: Error,
},
BadTransactionBalance,
}Expand description
A serialization error.
Variants
Io(Arc<Error>)
An io error that prevented deserialization
Parse(&'static str)
The data to be deserialized was malformed.
Utf8Error(Utf8Error)
A string was not UTF-8.
Note: Rust String and str are always UTF-8.
TryFromSliceError(TryFromSliceError)
A slice was an unexpected length during deserialization.
TryFromIntError(TryFromIntError)
The length of a vec is too large to convert to a usize (and thus, too large to allocate on this platform)
FromHexError(FromHexError)
A string was not valid hexadecimal.
Amount
An error caused when validating a zatoshi Amount
BadTransactionBalance
Invalid transaction with a non-zero balance and no Sapling shielded spends or outputs.
Transaction does not conform to the Sapling consensus rule.